pub struct CodeConfig {
pub name: String,
pub type_dict: HashMap<String, String>,
pub name_dict: HashMap<String, String>,
pub global_cfg: HashMap<String, String>,
}Expand description
Language-specific configuration map.
Fields
name: StringName of the configuration (can be cpp or rust).
type_dict: HashMap<String, String>Maps abstract type to overriden, language-specific type. Can be empty if no overrides are specified in config.
name_dict: HashMap<String, String>Maps abstract name to overriden, language-specific name (variables, functions, attributes etc.). Can be empty if no overrides are specified in config.
global_cfg: HashMap<String, String>List of global configuration data for given language.